/*
 * Copyright 2012 ETH Zuerich, CISD
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ch.systemsx.cisd.common.serviceconversation.server;

import java.io.Serializable;

/**
 * A value object holding progress info about remote method execution.
 * 
 * @author anttil
 */
public class ProgressInfo implements Serializable
{

    private static final long serialVersionUID = -3692359907946988354L;

    private String label;

    private Integer totalItemsToProcess;

    private Integer numItemsProcessed;

    public ProgressInfo(String label)
    {
        this.label = label;
    }

    public ProgressInfo(String label, Integer totalItemsToProcess, Integer numItemsProcessed)
    {
        this.label = label;
        this.totalItemsToProcess = totalItemsToProcess;
        this.numItemsProcessed = numItemsProcessed;
    }

    @Override
    public String toString()
    {
        if (this.numItemsProcessed == null && this.totalItemsToProcess == null)
        {
            return "ProgressInfo: " + this.label;
        } else
        {
            return "ProgressInfo: " + this.label + " " + this.numItemsProcessed + "/"
                    + this.totalItemsToProcess;
        }
    }

}
